summaryrefslogtreecommitdiff
path: root/t/mkinst3.sh
diff options
context:
space:
mode:
authorStefano Lattarini <stefano.lattarini@gmail.com>2012-05-20 18:26:01 +0200
committerStefano Lattarini <stefano.lattarini@gmail.com>2012-05-21 09:25:45 +0200
commit878d61d615bbd1ea852638a9dfbb4e2ca82aebc8 (patch)
tree42d347272cf3f008b734504491bc3cf4522bd080 /t/mkinst3.sh
parentd7734861fe537da7a76ce569427264f1421e459d (diff)
downloadautomake-878d61d615bbd1ea852638a9dfbb4e2ca82aebc8.tar.gz
[ng] mkinstalldirs: remove support for the script and the variable
According to our documentation: mkinstalldirs used to be a wrapper around 'mkdir -p', which is not portable. Now we prefer to use 'install-sh -d' when configure finds that 'mkdir -p' does not work, this makes one less script to distribute. For backward compatibility mkinstalldirs is still used and distributed when automake finds it in a package. But it is no longer installed automatically, and it should be safe to remove it. So we remove the 'mkinstalldirs' as well as its companion $(mkinstalldirs) variable from Automake-NG altogether. * NG-NEWS, doc/automake-ng.texi: Update. * automake.in (handle_configure): Don not require nor distribute the 'mkinstalldirs' script anymore. Do not define the $(mkinstalldirs) variable. (@common_files): Do not report 'mkinstalldirs' anymore. Reformat the array while we are at it, to make it easier to add or remove entries in the future. * lib/mkinstalldirs: Delete this file. * Makefile.am (dist_script_DATA): Remove it. (check-coverage-run, recheck-coverage-run): Use $(MKDIR_P), not $(mkinstalldirs), to create the 'cover_db' directory. * syntax-checks.mk (sc_mkinstalldirs): Adjust to verify we have mo more instances of 'mkinstalldirs'. * contrib/multilib/config-ml.in: Remove comment referencing the 'mkinstalldirs' script. * t/auxdir.sh: Adjust to use 'py-compile' rather than 'mkinstalldirs'. * t/auxdir6.sh: Likewise. * t/auxdir7.sh: Likewise. * t/auxdir8.sh: Likewise. * t/pr9.sh: Adjust comments to avoid spuriously triggering the 'sc_mkinstalldirs' maintainer check. * t/mkinst3.sh: Converted to test 'install-sh -d' rather than 'mkinstalldirs'. * t/subdir.sh: Adjust comments. * t/werror.sh: Use 'am_create_testdir=empty' rather than removing the install-sh, depcomp, missing and mkinstalldirs scripts by hand. * t/mkinstall.sh: Remove as obsolete. * t/instman2.sh: Likewise. Signed-off-by: Stefano Lattarini <stefano.lattarini@gmail.com>
Diffstat (limited to 't/mkinst3.sh')
-rwxr-xr-xt/mkinst3.sh18
1 files changed, 10 insertions, 8 deletions
diff --git a/t/mkinst3.sh b/t/mkinst3.sh
index fbe01c652..79485349a 100755
--- a/t/mkinst3.sh
+++ b/t/mkinst3.sh
@@ -14,7 +14,7 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# Test mkinstalldirs with spaces in directory names.
am_create_testdir=empty
. ./defs || Exit 1
@@ -24,15 +24,15 @@ mkdir '~a b' && mkdir '~a b/-x y' \
|| skip_ "directory names with spaces and metacharacters not accepted"
rm -rf '~a b'
-get_shell_script mkinstalldirs
+get_shell_script install-sh
-# Test mkinstalldirs with the installed mkdir.
+# Test with the installed mkdir.
-./mkinstalldirs '~a b/-x y'
+./install-sh -d '~a b/-x y'
test -d '~a b/-x y'
rm -rf '~a b'
# Trick mkinstalldirs into thinking mkdir does not support -p.
mkdir bin
cat >bin/mkdir <<'EOF'
@@ -54,12 +54,14 @@ export AM_PATH
PATH=`pwd`/bin$PATH_SEPARATOR$PATH
export PATH
-# Test mkinstalldirs without mkdir -p.
+# Test without mkdir -p.
-./mkinstalldirs '~a b/-x y'
+./install-sh -d '~a b/-x y'
test -d '~a b/-x y'
rm -rf '~a b'
-./mkinstalldirs "`pwd`///~a b//-x y"
+./install-sh -d "`pwd`///~a b//-x y"
test -d "`pwd`/~a b/-x y"
rm -rf '~a b'
+
+:
@@ -14,7 +14,7 @@
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
-# Test mkinstalldirs with spaces in directory names.
+# Test "install-sh -d" with spaces in directory names.
am_create_testdir=empty
. ./defs || Exit 1
@@ -24,15 +24,15 @@ mkdir '~a b' && mkdir '~a b/-x y' \
test -d '~a b/-x y'
rm -rf '~a b'
-# Trick mkinstalldirs into thinking mkdir does not support -p.
+# Trick install-sh into thinking mkdir does not support -p.
mkdir bin
cat >bin/mkdir <<'EOF'